跳到主要内容

Audio

搜索

结构体 Audio 

源代码
pub struct Audio(pub Encoder);

Tuple Fields

0: Encoder

实现

源代码

impl Audio

源代码

pub fn open(self) -> Result<Encoder, Error>

源代码

pub fn open_as<E: Encoder>(self, codec: E) -> Result<Encoder, Error>

源代码

pub fn open_with(self, options: Dictionary<'_>) -> Result<Encoder, Error>

源代码

pub fn open_as_with<E: Encoder>( self, codec: E, options: Dictionary<'_>, ) -> Result<Encoder, Error>

源代码

pub fn set_rate(&mut self, rate: i32)

源代码

pub fn rate(&self) -> u32

源代码

pub fn set_format(&mut self, value: Sample)

源代码

pub fn format(&self) -> Sample

源代码

pub fn set_channel_layout(&mut self, value: ChannelLayout)

源代码

pub fn channel_layout(&self) -> ChannelLayout

源代码

pub fn channels(&self) -> u16

Methods from Deref<Target = Super>

源代码

pub fn send_frame(&mut self, frame: &Frame) -> Result<(), Error>

源代码

pub fn send_eof(&mut self) -> Result<(), Error>

Sends a NULL packet to the encoder to signal end of stream and enter draining mode.

源代码

pub fn receive_packet<P: Mut>(&mut self, packet: &mut P) -> Result<(), Error>

源代码

pub fn set_bit_rate(&mut self, value: usize)

源代码

pub fn set_max_bit_rate(&mut self, value: usize)

源代码

pub fn set_tolerance(&mut self, value: usize)

源代码

pub fn set_quality(&mut self, value: usize)

源代码

pub fn set_compression(&mut self, value: Option<usize>)

Methods from Deref<Target = Context>

源代码

pub unsafe fn as_ptr(&self) -> *const AVCodecContext

源代码

pub unsafe fn as_mut_ptr(&mut self) -> *mut AVCodecContext

源代码

pub fn codec(&self) -> Option<Codec>

源代码

pub fn medium(&self) -> Type

源代码

pub fn set_flags(&mut self, value: Flags)

源代码

pub fn id(&self) -> Id

源代码

pub fn compliance(&mut self, value: Compliance)

源代码

pub fn debug(&mut self, value: Debug)

源代码

pub fn set_threading(&mut self, config: Config)

源代码

pub fn threading(&self) -> Config

源代码

pub fn set_parameters<P: Into<Parameters>>( &mut self, parameters: P, ) -> Result<(), Error>

源代码

pub fn time_base(&self) -> Rational

源代码

pub fn set_time_base<R: Into<Rational>>(&mut self, value: R)

源代码

pub fn frame_rate(&self) -> Rational

源代码

pub fn set_frame_rate<R: Into<Rational>>(&mut self, value: Option<R>)

trait 实现

源代码

impl AsMut<Context> for Audio

源代码

fn as_mut(&mut self) -> &mut Context

Converts this type into a mutable reference of the (usually inferred) input type.
源代码

impl AsRef<Context> for Audio

源代码

fn as_ref(&self) -> &Context

Converts this type into a shared reference of the (usually inferred) input type.
源代码

impl Deref for Audio

源代码

type Target = Encoder

解引用之后得到的类型。
源代码

fn deref(&self) -> &<Self as Deref>::Target

解引用该值。
源代码

impl DerefMut for Audio

源代码

fn deref_mut(&mut self) -> &mut <Self as Deref>::Target

Mutably dereferences the value.

自动 trait 实现



impl Freeze for Audio



impl !RefUnwindSafe for Audio



impl Send for Audio



impl !Sync for Audio



impl Unpin for Audio



impl UnsafeUnpin for Audio



impl !UnwindSafe for Audio

blanket 实现

源代码

impl<T> Any for T
where T: 'static + ?Sized,

源代码

fn type_id(&self) -> TypeId

获取 selfTypeId阅读更多
源代码

impl<T> Borrow<T> for T
where T: ?Sized,

源代码

fn borrow(&self) -> &T

从拥有的值不可变地借用。 阅读更多
源代码

impl<T> BorrowMut<T> for T
where T: ?Sized,

源代码

fn borrow_mut(&mut self) -> &mut T

从拥有的值可变地借用。 阅读更多
源代码

impl<T> From<T> for T

源代码

fn from(t: T) -> T

原样返回参数。

源代码

impl<T, U> Into<U> for T
where U: From<T>,

源代码

fn into(self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of From<T> for U 实现选择执行的操作。

源代码

impl<P, T> Receiver for P
where P: Deref<Target = T> + ?Sized, T: ?Sized,

源代码

type Target = T

🔬This is a nightly-only experimental API. (arbitrary_self_types)
The target type on which the method may be called.
源代码

impl<T, U> TryFrom<U> for T
where U: Into<T>,

源代码

type Error = Infallible

转换出错时返回的类型。
源代码

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

执行该转换。
源代码

impl<T, U> TryInto<U> for T
where U: TryFrom<T>,

源代码

type Error = <U as TryFrom<T>>::Error

转换出错时返回的类型。
源代码

fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

执行该转换。